;+
; NAME:
;     WITH_INT
; PURPOSE:
;     Integrate Withbroe models to find radial variation of
;       coronal brightness in soft X-rays. See WITHBROE for
;       model details and a reference.
; CATEGORY:
;     Yohkoh support
; CALLING SEQUENCE:
;     flux = with_int(model_type, height, int_step=int_step)
; INPUTS:
;     Type of Withbroe model (see WITHBROE); 3 => polar hole (min)
; OPTIONAL (KEYWORD) INPUT PARAMETERS:
;     int_step is the number of steps per 10 R_sun in the integration,
;       default is 100
;     impact_par is the impact parameter in R_o (can be <1; default is
;       .01, .02, ... 2.00
; OUTPUTS:
;     structure containing the following tags:
;       model_name
;       height, the impact parameter in R_o
;       thinal, the Al.1 counts
;       dag,    the AlMg counts
;       t_sky,  the Withbroe model temperature at r = impact parameter
;       t_eff,  the effective temperature after integration to 10 R_o
;       em_eff, the effective emission measure ditto
;       dem,    the [t, em] distribution (fltarr(2, int_step))
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; ROUTINES CALLED:
;	      WITHBROE, SXT_FLUX, GT_PIX_SIZE
; MODIFICATION HISTORY:
;	      HSH Oct. 16, 1993
;       HSH Mar. 30, 1994 added Dag to the output
;       HSH Apr.  3, 1994 converted to a function and fixed bugs
;       HSH Mar. 19, 2000 vectorized and structuralized
;-
function with_int, model_type, impact_par = impact_par, $
  int_step=int_step, qstop=qstop 
;
if n_elements(int_step) eq 0 then int_step = 1000
height = (1.+findgen(200))/100.
if n_elements(impact_par) ne 0 then height = impact_par
out = {with_str, model_name:'', ht:0., thinal:0., dag:0., t_sky:0., $
  t_eff:0., em_eff:0.,dem:fltarr(2,int_step)} 
model_nn = ['Quiet_corona','Polar_hole_max','Eq_hole_min',$
  'Polar_hole_min'] 
out = replicate(out,n_elements(height)) 
temp = fltarr(int_step)
dense2 = fltarr(int_step)
integrand2 = fltarr(int_step)
integrand3 = fltarr(int_step)
r_o = get_rb0p('1-apr',/r)
arcsec = 6.96e10/r_o
pix    = gt_pix_size()
pixare = pix^2 * arcsec^2
pixvol = pix^3 * arcsec^3
delta_ell = 10.*6.96e10/int_step 
unit_vol = pixare * delta_ell
for i = 0, n_elements(height)-1 do begin
  out(i).model_name = model_nn(model_type)
  out(i).ht = height(i)
  ell = 10 * findgen(int_step)/int_step
  radii = sqrt(ell^2 + (height(i))^2)
  above = where(radii gt 1 and radii lt 10, n_above)
  model = withbroe(radii(above),model_type)
  temp = reform(alog10(1e6*model(1,*)))
  d_temp = abs(temp(1:*) - temp(0:n_above-2))
  d_temp = [d_temp(0),d_temp]
  out(i).t_sky = temp(0)
  if out(i).ht lt 1. then out(i).t_sky = $
    alog10((withbroe(1., model_type))(1))
  dense2 = model(2,*)^2
  em_factor = 10^(alog10(dense2) + alog10(unit_vol) -44.)
  out(i).dem(0,above) = reform(temp)
  out(i).dem(1,above) = reform(em_factor)/d_temp
  integrand2 = sxt_flux(temp,2) * em_factor 
  integrand3 = sxt_flux(temp,3) * em_factor 
  mult = 1.                            ; visible hemisphere only
  if out(i).ht gt 1. then mult = 2.    ; foreground + background corona
  out(i).thinal = total(integrand2) * mult 
  out(i).dag    = total(integrand3) * mult 
  sxt_teem,2,out(i).thinal,3,out(i).dag,te,em
  out(i).t_eff = te
  out(i).em_eff = em
endfor
if n_elements(qstop) then stop
return, out
end
